@@ -3,7 +3,7 @@ import { css } from '@emotion/css';
 import { GrafanaTheme2, renderMarkdown } from '@grafana/data';
 import { Box, useStyles2 } from '@grafana/ui';
 
-import { Spec } from '../api/clients/banners';
+import { Spec } from '../api/clients/banners/v0alpha1';
 
 type Props = Pick<Spec, 'message' | 'variant'>;
 
